.. _whatsnew:

**********
What's New
**********

These are new features and improvements of note in each release.

.. include:: whatsnew/v1.6.0.rst
.. include:: whatsnew/v1.5.3.rst
.. include:: whatsnew/v1.5.2.rst
.. include:: whatsnew/v1.5.1.rst
.. include:: whatsnew/v1.5.0.rst
.. include:: whatsnew/v1.4.1.rst
.. include:: whatsnew/v1.4.0.rst
.. include:: whatsnew/v1.3.0.rst
.. include:: whatsnew/v1.2.2.rst
.. include:: whatsnew/v1.2.1.rst
.. include:: whatsnew/v1.2.0.rst
.. include:: whatsnew/v1.1.0.rst
.. include:: whatsnew/v1.0.3.rst
.. include:: whatsnew/v1.0.2.rst
.. include:: whatsnew/v1.0.1.rst
.. include:: whatsnew/v1.0.0.rst
.. include:: whatsnew/v0.1.5.rst
.. include:: whatsnew/v0.1.4.rst
.. include:: whatsnew/v0.1.3.rst
.. include:: whatsnew/v0.1.2.rst
.. include:: whatsnew/v0.1.1.rst
.. include:: whatsnew/v0.1.0.rst
